@@ -3,14 +3,16 @@ use Moose;
 
 extends 'Shell::Amazon::S3::Command';
 
-sub parse_tokens {
+override 'parse_tokens', sub {
     my ($self, $token) = @_;
     return $token;
-}
+};
 
 sub execute {
     my ($self, $args) = @_;
     return 'EXIT';
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
